@@ -471,6 +471,20 @@ def get_feats_hot_encoded(feature_names=keys, filename="feats_encoded.json"):
     return new_dat
 
 
+x, y, z = get_specie_data()
+info_z = {}
+for i, j in y.items():
+    info_z[j["Z"]] = i
+
+
+def atomic_numbers_to_symbols(numbers=[1, 2, 3, 4]):
+    """Convert atomic number array to atomic symbols."""
+    symbs = []
+    for i in numbers:
+        symbs.append(info_z[i])
+    return symbs
+
+
 # get_digitized_feats_hot_encoded()
 """
 if __name__ == "__main__":
