@@ -46,15 +46,38 @@ poscar_path = os.path.join(
     "POSCAR",
 )
 
-cif_example = os.path.join(os.path.dirname(__file__), "1000052.cif",)
-cif_example2 = os.path.join(os.path.dirname(__file__), "Bacomp.cif",)
-cif_example3 = os.path.join(os.path.dirname(__file__), "mock.cif",)
+cif_example = os.path.join(
+    os.path.dirname(__file__),
+    "1000052.cif",
+)
+cif_example2 = os.path.join(
+    os.path.dirname(__file__),
+    "Bacomp.cif",
+)
+cif_example3 = os.path.join(
+    os.path.dirname(__file__),
+    "mock.cif",
+)
+cif_example4 = os.path.join(
+    os.path.dirname(__file__),
+    "exp_000034.cif",
+)
+cif_example5 = os.path.join(
+    os.path.dirname(__file__),
+    "1000000.cif",
+)
 
 
 def test_from_cif():
     a = Atoms.from_cif(cif_example)
     a = Atoms.from_cif(cif_example2)
     a = Atoms.from_cif(cif_example3)
+    a = Atoms.from_cif(cif_example4)
+    a = Atoms.from_cif(cif_example5)
+    f = open(cif_example, "r")
+    lines = f.read()
+    f.close()
+    x = Atoms.from_cif(from_string=lines)
 
 
 def test_basic_atoms():
