@@ -1,8 +1,9 @@
-from jarvis.core.lattice import Lattice
+from jarvis.core.lattice import Lattice, get_2d_lattice
 import numpy as np
 from jarvis.db.figshare import data
 from jarvis.core.atoms import Atoms
 
+
 def test_lat():
     box = [[10, 0, 0], [0, 10, 0], [0, 0, 10]]
     lat = Lattice(box)
@@ -37,11 +38,17 @@ def test_lat():
         10.0,
         10.0,
     )
-    d=data('dft_3d')
+    d = data("dft_3d")
     for i in d:
-      if i['jid'] == 'JVASP-588':
-         atoms=Atoms.from_dict(i['atoms'])
-         lll = atoms.lattice._calculate_lll()
-         assert lll[1][0][0] == -1
+        if i["jid"] == "JVASP-588":
+            atoms = Atoms.from_dict(i["atoms"])
+            lll = atoms.lattice._calculate_lll()
+            assert lll[1][0][0] == -1
+    d = data("dft_2d")
+    for i in d:
+        if i["jid"] == "JVASP-667":
+            atoms = i["atoms"]
+            a = get_2d_lattice(atoms)
+
 
 # test_lat()
